@@ -13,6 +13,8 @@
 #' @param original A single logical. Should the range values be in the natural
 #'  units (`TRUE`) or in the transformed space (`FALSE`, if applicable)?
 #'
+#' @inheritParams new-param
+#'
 #' @return
 #'
 #' `range_validate()` returns the new range if it passes the validation
@@ -42,15 +44,25 @@
 #'   range_get()
 #'
 #' @export
-range_validate <- function(object, range, ukn_ok = TRUE) {
+range_validate <- function(object,
+                           range,
+                           ukn_ok = TRUE,
+                           ...,
+                           call = caller_env()
+                           ) {
   ukn_txt <- if (ukn_ok) {
-    "`Inf` and `unknown()` are acceptable values."
+    c(i = "{.code Inf} and {.code unknown()} are acceptable values.")
   } else {
-    ""
+    NULL
   }
   if (length(range) != 2) {
-    rlang::abort(
-      paste("`range` must have two values: an upper and lower bound.", ukn_txt)
+    cli::cli_abort(
+      c(
+        x = "{.arg range} must have two values: an upper and lower bound.",
+        i = "{length(range)} value{?s} {?was/were} provided.",
+        ukn_txt
+      ),
+      call = call
     )
   }
 
@@ -60,19 +72,28 @@ range_validate <- function(object, range, ukn_ok = TRUE) {
 
   if (!ukn_ok) {
     if (any(is_unk)) {
-      rlang::abort("Cannot validate ranges when they contains 1+ unknown values.")
+      cli::cli_abort(
+        "Cannot validate ranges when they contains 1+ unknown values.",
+        call = call
+      )
     }
     if (!any(is_num)) {
-      rlang::abort("`range` should be numeric.")
+      cli::cli_abort("{.arg range} should be numeric.", call = call)
     }
 
     # TODO check with transform
   } else {
     if (any(is_na[!is_unk])) {
-      rlang::abort("Value ranges must be non-missing.", ukn_txt)
+      cli::cli_abort(
+        c(x = "Value ranges must be non-missing.", ukn_txt),
+        call = call
+      )
     }
     if (any(!is_num[!is_unk])) {
-      rlang::abort("Value ranges must be numeric.", ukn_txt)
+      cli::cli_abort(
+        c("Value ranges must be numeric.", ukn_txt),
+        call = call
+      )
     }
   }
   range
@@ -91,9 +112,12 @@ range_get <- function(object, original = TRUE) {
 
 #' @export
 #' @rdname range_validate
-range_set <- function(object, range) {
+range_set <- function(object, range, call = caller_env()) {
   if (length(range) != 2) {
-    rlang::abort("`range` should have two elements.")
+    cli::cli_abort(
+      "{.arg range} should have two elements, not {length(range)}.",
+      call = call
+    )
   }
   if (inherits(object, "quant_param")) {
     object <-
@@ -106,7 +130,11 @@ range_set <- function(object, range) {
         label = object$label
       )
   } else {
-    rlang::abort("`object` should be a 'quant_param' object")
+    cli::cli_abort(
+      "{.arg object} should be a {.cls quant_param} object,
+      not {.obj_type_friendly {object}}.",
+      call = call
+    )
   }
   object
 }
