@@ -17,6 +17,8 @@
 #' @param original A single logical. Should the range values be in the natural
 #'  units (`TRUE`) or in the transformed space (`FALSE`, if applicable)?
 #'
+#' @inheritParams new-param
+#'
 #' @return
 #'
 #' `value_validate()` throws an error or silently returns `values` if they are
@@ -70,12 +72,12 @@
 #' cost_complexity() %>% value_sample(2)
 #'
 #' @export
-value_validate <- function(object, values) {
+value_validate <- function(object, values, ..., call = caller_env()) {
   res <- switch(object$type,
     double = ,
-    integer = value_validate_quant(object, values),
+    integer = value_validate_quant(object, values, call = call),
     character = ,
-    logical = value_validate_qual(object, values)
+    logical = value_validate_qual(object, values, call = call)
   )
   unlist(res)
 }
@@ -138,11 +140,22 @@ value_seq <- function(object, n, original = TRUE) {
 
 value_seq_dbl <- function(object, n, original = TRUE) {
   if (!is.null(object$values)) {
-    res <- object$values[1:min(length(object$values), n)]
+    n_safely <- min(length(object$values), n)
+    res <- object$values[seq_len(n_safely)]
   } else {
+    range_lower <- min(unlist(object$range))
+    if (!object$inclusive["lower"]) {
+      range_lower <- range_lower + .Machine$double.eps
+    }
+
+    range_upper <- max(unlist(object$range))
+    if (!object$inclusive["upper"]) {
+      range_upper <- range_upper - .Machine$double.eps
+    }
+
     res <- seq(
-      from = min(unlist(object$range)),
-      to = max(unlist(object$range)),
+      from = range_lower,
+      to = range_upper,
       length.out = n
     )
   }
@@ -155,11 +168,22 @@ value_seq_dbl <- function(object, n, original = TRUE) {
 
 value_seq_int <- function(object, n, original = TRUE) {
   if (!is.null(object$values)) {
-    res <- object$values[1:min(length(object$values), n)]
+    n_safely <- min(length(object$values), n)
+    res <- object$values[seq_len(n_safely)]
   } else {
+    range_lower <- min(unlist(object$range))
+    if (!object$inclusive["lower"]) {
+      range_lower <- range_lower + 1L
+    }
+
+    range_upper <- max(unlist(object$range))
+    if (!object$inclusive["upper"]) {
+      range_upper <- range_upper - 1L
+    }
+
     res <- seq(
-      from = min(unlist(object$range)),
-      to = max(unlist(object$range)),
+      from = range_lower,
+      to = range_upper,
       length.out = n
     )
   }
@@ -175,7 +199,8 @@ value_seq_int <- function(object, n, original = TRUE) {
 }
 
 value_seq_qual <- function(object, n) {
-  res <- object$values[1:min(n, length(object$values))]
+  n_safely <- min(length(object$values), n)
+  res <- object$values[seq_len(n_safely)]
   res
 }
 
@@ -197,10 +222,20 @@ value_sample <- function(object, n, original = TRUE) {
 
 value_samp_dbl <- function(object, n, original = TRUE) {
   if (is.null(object$values)) {
+    range_lower <- min(unlist(object$range))
+    if (!object$inclusive["lower"]) {
+      range_lower <- range_lower + .Machine$double.eps
+    }
+
+    range_upper <- max(unlist(object$range))
+    if (!object$inclusive["upper"]) {
+      range_upper <- range_upper - .Machine$double.eps
+    }
+
     res <- runif(
       n,
-      min = min(unlist(object$range)),
-      max = max(unlist(object$range))
+      min = range_lower,
+      max = range_upper
     )
   } else {
     res <- sample(
@@ -218,11 +253,22 @@ value_samp_dbl <- function(object, n, original = TRUE) {
 value_samp_int <- function(object, n, original = TRUE) {
   if (is.null(object$trans)) {
     if (is.null(object$values)) {
+      range_lower <- min(unlist(object$range))
+      if (!object$inclusive["lower"]) {
+        range_lower <- range_lower + 1L
+      }
+
+      range_upper <- max(unlist(object$range))
+      if (!object$inclusive["upper"]) {
+        range_upper <- range_upper - 1L
+      }
+
       res <- sample(
-        min(unlist(object$range)):max(unlist(object$range)),
+        seq(from = range_lower, to = range_upper),
         size = n,
         replace = TRUE
       )
+      res <- as.integer(res)
     } else {
       res <- sample(
         object$values,
@@ -232,10 +278,20 @@ value_samp_int <- function(object, n, original = TRUE) {
     }
   } else {
     if (is.null(object$values)) {
+      range_lower <- min(unlist(object$range))
+      if (!object$inclusive["lower"]) {
+        range_lower <- range_lower + .Machine$double.eps
+      }
+
+      range_upper <- max(unlist(object$range))
+      if (!object$inclusive["upper"]) {
+        range_upper <- range_upper - .Machine$double.eps
+      }
+
       res <- runif(
         n,
-        min = min(unlist(object$range)),
-        max = max(unlist(object$range))
+        min = range_lower,
+        max = range_upper
       )
     } else {
       res <- sample(
@@ -305,11 +361,9 @@ inv_wrap <- function(x, object) {
 value_set <- function(object, values) {
   check_for_unknowns(values)
   if (length(values) == 0) {
-    rlang::abort("`values` should at least one element.")
-  }
-  if (!inherits(object, "param")) {
-    rlang::abort("`object` should be a 'param' object")
+    cli::cli_abort("{.arg values} must have at least one element.")
   }
+  check_param(object)
 
   if (inherits(object, "quant_param")) {
     object <-
