@@ -27,7 +27,7 @@ dropout <- function(range = c(0, 1), trans = NULL) {
 
 #' @rdname dropout
 #' @export
-epochs <- function(range = c(1L, 1000L), trans = NULL) {
+epochs <- function(range = c(10L, 1000L), trans = NULL) {
   new_quant_param(
     type = "integer",
     range = range,
@@ -53,7 +53,20 @@ hidden_units <- function(range = c(1L, 10L), trans = NULL) {
 
 #' @export
 #' @rdname dropout
-batch_size <- function(range = c(unknown(), unknown()), trans = log2_trans()) {
+hidden_units_2 <- function(range = c(1L, 10L), trans = NULL) {
+  new_quant_param(
+    type = "integer",
+    range = range,
+    inclusive = c(TRUE, TRUE),
+    trans = trans,
+    label = c(hidden_units = "# Hidden Units Layer 2"),
+    finalize = NULL
+  )
+}
+
+#' @export
+#' @rdname dropout
+batch_size <- function(range = c(unknown(), unknown()), trans = transform_log2()) {
   new_quant_param(
     type = "integer",
     range = range,
