@@ -1,12 +1,11 @@
 #' Parameters for class-imbalance sampling
 #'
 #' For up- and down-sampling methods, these parameters control how much data are
-#' added or removed from the training set.
+#' added or removed from the training set. Used in `themis::step_rose()`, 
+#' `themis::step_smotenc()`, `themis::step_bsmote()`, `themis::step_upsample()`, 
+#' `themis::step_downsample()`, and `themis::step_nearmiss()`.
 #'
 #' @inheritParams Laplace
-#' @details
-#' See `recipes::step_upsample()` and `recipes::step_downsample()` for the
-#' interpretation of these parameters.
 #' @examples
 #' under_ratio()
 #' over_ratio()
@@ -17,7 +16,6 @@ over_ratio <- function(range = c(0.8, 1.2), trans = NULL) {
     range = range,
     inclusive = c(TRUE, TRUE),
     trans = trans,
-    default = 1,
     label = c(over_ratio = "Over-Sampling Ratio"),
     finalize = NULL
   )
@@ -31,7 +29,6 @@ under_ratio <- function(range = c(0.8, 1.2), trans = NULL) {
     range = range,
     inclusive = c(TRUE, TRUE),
     trans = trans,
-    default = 1,
     label = c(under_ratio = "Under-Sampling Ratio"),
     finalize = NULL
   )
